@@ -112,7 +112,10 @@ QVariant QDjangoMetaField::toDatabase(const QVariant &value) const
 {
     if (d->type == QVariant::String && !d->null && value.isNull())
         return QString("");
-    else
+    else if (!d->foreignModel.isEmpty() && d->type == QVariant::Int && d->null && !value.toInt()) {
+        // store 0 foreign key as NULL if the field is NULL
+        return QVariant();
+    } else
         return value;
 }
 
@@ -227,6 +230,7 @@ QDjangoMetaModel::QDjangoMetaModel(const QObject *model)
             field.d->foreignModel = fkModel;
             field.d->db_column = dbColumnOption.isEmpty() ? QString::fromLatin1(field.d->name) : dbColumnOption;
             field.d->index = true;
+            field.d->null = nullOption;
             d->localFields << field;
             continue;
         }
